<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ca_ES">
<context>
    <name>About</name>
    <message>
        <location filename="about.ui" line="32"/>
        <source>About qdacco</source>
        <translation>Sobre qdacco</translation>
    </message>
    <message>
        <location filename="about.ui" line="58"/>
        <source>Close</source>
        <translation>Tanca</translation>
    </message>
    <message>
        <location filename="about.ui" line="73"/>
        <source>About</source>
        <translation>Quant a</translation>
    </message>
    <message>
        <location filename="about.ui" line="113"/>
        <source>qdacco 0.8.1</source>
        <translation>qdacco 0.8.1</translation>
    </message>
    <message>
        <location filename="about.ui" line="147"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;a href=&quot;http://www.catalandictionary.org/eng/?q=node/40&quot;&gt;&lt;span style=&quot; font-size:10pt; text-decoration: underline; color:#0057ae;&quot;&gt;http://www.catalandictionary.org/eng/?q=node/40&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:11pt; text-decoration: underline; color:#0057ae;&quot;&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:11pt;&quot;&gt;Application for searching the Dacco dictionary offline.&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:11pt;&quot;&gt;You can find Dacco at &lt;/span&gt;&lt;a href=&quot;http://www.catalandictionary.org&quot;&gt;&lt;span style=&quot; font-size:11pt; text-decoration: underline; color:#0000ff;&quot;&gt;http://www.catalandictionary.org&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <oldsource>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:14pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;a href=&quot;http://www.catalandictionary.org/eng/?q=node/40&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;http://www.catalandictionary.org/eng/?q=node/40&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; text-decoration: underline; color:#0057ae;&quot;&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:9pt;&quot;&gt;Application for searching the Dacco dictionary offline.&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:9pt;&quot;&gt;You can find Dacco at &lt;/span&gt;&lt;a href=&quot;http://www.catalandictionary.org&quot;&gt;&lt;span style=&quot; font-size:9pt; text-decoration: underline; color:#0000ff;&quot;&gt;http://www.catalandictionary.org&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</oldsource>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;a href=&quot;http://www.catalandictionary.org/eng/?q=node/40&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;http://www.catalandictionary.org/eng/?q=node/40&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; text-decoration: underline; color:#0057ae;&quot;&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:9pt;&quot;&gt;Aplicació per buscar a Dacco sense connexió.&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:9pt;&quot;&gt;Podeu trobar Dacco a: &lt;/span&gt;&lt;a href=&quot;http://www.catalandictionary.org&quot;&gt;&lt;span style=&quot; font-size:9pt; text-decoration: underline; color:#0000ff;&quot;&gt;http://www.catalandictionary.org&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="about.ui" line="168"/>
        <source>Author</source>
        <translation>Autor</translation>
    </message>
    <message>
        <location filename="about.ui" line="180"/>
        <source>Carles Pina i Estany, 2005, 2006, 2007, 2008, 2009, 2011, 2013</source>
        <translation></translation>
    </message>
    <message>
        <location filename="about.ui" line="199"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:14pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:9pt;&quot;&gt;Many thanks to:&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:9pt;&quot;&gt;Jordi Pina: Graphical support,&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:9pt;&quot;&gt;Leopold Palomo-Avellaneda: cmake transition&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:9pt;&quot;&gt;and many other people for their support.&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:9pt;&quot;&gt;Suggestions, patches, ideas, etc. to &lt;/span&gt;&lt;a href=&quot;mailto:carles@pina.cat&quot;&gt;&lt;span style=&quot; font-size:9pt; text-decoration: underline; color:#0000ff;&quot;&gt;carles@pina.cat&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:14pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:9pt;&quot;&gt;Moltes gràcies a:&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:9pt;&quot;&gt;Jordi Pina: gràfics,&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:9pt;&quot;&gt;Leopold Palomo-Avellaneda: transició a cmake&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:9pt;&quot;&gt;i altres pel seu suport i ajuda.&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:9pt;&quot;&gt;Suggerències, pegats, idees, etc. a &lt;/span&gt;&lt;a href=&quot;mailto:carles@pina.cat&quot;&gt;&lt;span style=&quot; font-size:9pt; text-decoration: underline; color:#0000ff;&quot;&gt;carles@pina.cat&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="about.ui" line="238"/>
        <source>License</source>
        <translation>Llicència</translation>
    </message>
    <message>
        <location filename="about.ui" line="244"/>
        <source>Program is GPL 3.0 licensed.

Data is LGPL licensed.</source>
        <translation>Programa llicenciat amb GPL 3.0

Dades llicenciades amb LGPL.</translation>
    </message>
    <message>
        <location filename="about.cpp" line="27"/>
        <source>qdacco version:</source>
        <translation>versió qdacco:</translation>
    </message>
</context>
<context>
    <name>Configure</name>
    <message>
        <location filename="configure.ui" line="32"/>
        <source>Configure</source>
        <translation>Configura</translation>
    </message>
    <message>
        <location filename="configure.ui" line="46"/>
        <source>Basic</source>
        <translation>Bàsica</translation>
    </message>
    <message>
        <location filename="configure.ui" line="52"/>
        <source>Default dictionary:</source>
        <translation>Diccionari per omissió:</translation>
    </message>
    <message>
        <location filename="configure.ui" line="63"/>
        <source>Catalan-&gt;English</source>
        <translation>Català-&gt;Anglès</translation>
    </message>
    <message>
        <location filename="configure.ui" line="68"/>
        <source>English-&gt;Catalan</source>
        <translation>Anglès-&gt;Català</translation>
    </message>
    <message>
        <location filename="configure.ui" line="76"/>
        <source>Default language:</source>
        <translation>Idioma per omissió:</translation>
    </message>
    <message>
        <location filename="configure.ui" line="87"/>
        <source>Catalan</source>
        <translation>Català</translation>
    </message>
    <message>
        <location filename="configure.ui" line="92"/>
        <source>English</source>
        <translation>Anglès</translation>
    </message>
    <message>
        <location filename="configure.ui" line="100"/>
        <source>Ignore accents:</source>
        <translation>Ignorar accents:</translation>
    </message>
    <message>
        <location filename="configure.ui" line="120"/>
        <source>Match case:</source>
        <translation>Distingeix majúscules:</translation>
    </message>
    <message>
        <location filename="configure.ui" line="140"/>
        <source>Name:</source>
        <translation>Nom:</translation>
    </message>
    <message>
        <location filename="configure.ui" line="150"/>
        <source>If you send some suggestions or bug reports to Dacco, we will know your name. This is not compulsory</source>
        <translation>Si envieu suggerències o reportes errades a Dacco sabrem el vostre nom. No és obligatori</translation>
    </message>
    <message>
        <location filename="configure.ui" line="157"/>
        <source>E-Mail:</source>
        <translation>Correu electrònic:</translation>
    </message>
    <message>
        <location filename="configure.ui" line="167"/>
        <source>If you send some suggestions or bug reports to Dacco, we will know your e-mail. This is not compulsory</source>
        <translation>Si envieu suggerències o reportes errades a Dacco sabrem el teu correu electrònic. No és obligatori</translation>
    </message>
    <message>
        <location filename="configure.ui" line="175"/>
        <source>Advanced</source>
        <translation>Avançada</translation>
    </message>
    <message>
        <location filename="configure.ui" line="181"/>
        <source>Dictionary directory:</source>
        <translation>Directori del diccionari:</translation>
    </message>
    <message>
        <location filename="configure.ui" line="191"/>
        <location filename="configure.ui" line="230"/>
        <source>Select the dictionaries directory on your system</source>
        <translation>Seleccioneu el directori &quot;dictionaries&quot; del vostre sistema</translation>
    </message>
    <message>
        <location filename="configure.ui" line="209"/>
        <location filename="configure.ui" line="248"/>
        <location filename="configure.ui" line="286"/>
        <location filename="configure.ui" line="331"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="configure.ui" line="220"/>
        <source>Browser:</source>
        <translation>Navegador:</translation>
    </message>
    <message>
        <location filename="configure.ui" line="259"/>
        <source>Festival executable:</source>
        <translation>Executable Festival:</translation>
    </message>
    <message>
        <location filename="configure.ui" line="297"/>
        <source>Autocomplete:</source>
        <translation>Autocompletar:</translation>
    </message>
    <message>
        <location filename="configure.ui" line="314"/>
        <source>Single instance:</source>
        <translation>Instància única:</translation>
    </message>
    <message>
        <location filename="configure.cpp" line="58"/>
        <location filename="configure.cpp" line="63"/>
        <location filename="configure.cpp" line="67"/>
        <location filename="configure.cpp" line="71"/>
        <source>Information</source>
        <translation>Informació</translation>
    </message>
    <message>
        <location filename="configure.cpp" line="58"/>
        <source>You should select the &quot;dictionaries&quot; directory and click &quot;Open&quot;</source>
        <translation>Haurieu de seleccionar el directori &quot;dictionaries&quot; i fer clic a &quot;Obrir&quot;</translation>
    </message>
    <message>
        <location filename="configure.cpp" line="63"/>
        <source>Some entries has links (e.g. to photos). Select which browser do you want to use</source>
        <translation>Algunes entrades tenen enllaços (per exemple fotos). Seleccioneu el navegador que voleu utilitzar</translation>
    </message>
    <message>
        <location filename="configure.cpp" line="67"/>
        <source>You can produce a synthesised pronunciation of your query results with qdacco. To use this feature you must have Festival installed on your system.&lt;P&gt;Festival webpage: &lt;A HREF=&quot;http://www.cstr.ed.ac.uk/projects/festival/&quot;&gt;http://www.cstr.ed.ac.uk/projects/festival/&lt;/A&gt;</source>
        <translation>Podeu produir una pronunciació sintetitzada pels resultats de qdacco. Per utilitzar aquesta característica cal tenir instal·lat Festival al vostre sistema. &lt;P&gt;Pàgina Web de festival: &lt;A HREF=&quot;http://www.cstr.ed.ac.uk/projects/festival/&quot;&gt;http://www.cstr.ed.ac.uk/projects/festival/&lt;/A&gt;</translation>
    </message>
    <message>
        <location filename="configure.cpp" line="71"/>
        <source>Enabling: you will have a trayicon next to the clock and only want qdacco will be running all the time. If you launch a new one it will bring to the foreground the old one. Disabling: you will not have a trayicon, and everytime that you launch a new qdacco you will have a new qdacco instance.</source>
        <translation>Activat: tindreu una icona al costat del rellotge i només un qdacco s&apos;executarà a la vegada. Si executeu un nou qdacco, l&apos;anterior serà portat a primer pla. Desactivat: no tindreu cap icona al costat del rellotge, i cada vegada que executeu un nou qdacco en tindreu una instància nova.</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="main.ui" line="27"/>
        <source>qdacco</source>
        <translation></translation>
    </message>
    <message>
        <location filename="main.ui" line="78"/>
        <source>&amp;Search</source>
        <translation>Ce&amp;rca</translation>
    </message>
    <message>
        <location filename="main.ui" line="81"/>
        <source>Ctrl+F</source>
        <translation></translation>
    </message>
    <message>
        <location filename="main.ui" line="167"/>
        <source>&amp;Help</source>
        <translation>A&amp;juda</translation>
    </message>
    <message>
        <location filename="main.ui" line="173"/>
        <source>&amp;File</source>
        <translation>&amp;Fitxer</translation>
    </message>
    <message>
        <location filename="main.ui" line="182"/>
        <source>&amp;Edit</source>
        <translation>E&amp;dita</translation>
    </message>
    <message>
        <location filename="main.ui" line="198"/>
        <location filename="main.ui" line="201"/>
        <source>&amp;Copy</source>
        <translation>&amp;Copia</translation>
    </message>
    <message>
        <location filename="main.ui" line="204"/>
        <location filename="main.cpp" line="69"/>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <location filename="main.ui" line="207"/>
        <source>Ctrl+C</source>
        <translation></translation>
    </message>
    <message>
        <location filename="main.ui" line="215"/>
        <location filename="main.ui" line="218"/>
        <source>&amp;About qdacco</source>
        <translation>&amp;Quant a qdacco</translation>
    </message>
    <message>
        <location filename="main.ui" line="221"/>
        <source>About</source>
        <translation>Quant a</translation>
    </message>
    <message>
        <location filename="main.ui" line="229"/>
        <source>editConfigure</source>
        <translation></translation>
    </message>
    <message>
        <location filename="main.ui" line="237"/>
        <location filename="main.ui" line="240"/>
        <source>&amp;Quit</source>
        <translation>&amp;Abandona</translation>
    </message>
    <message>
        <location filename="main.ui" line="243"/>
        <source>Quit</source>
        <translation>Abandona</translation>
    </message>
    <message>
        <location filename="main.ui" line="246"/>
        <source>Ctrl+W</source>
        <translation></translation>
    </message>
    <message>
        <location filename="main.ui" line="254"/>
        <location filename="main.ui" line="257"/>
        <source>&amp;Configure</source>
        <translation>&amp;Configura</translation>
    </message>
    <message>
        <location filename="main.ui" line="260"/>
        <source>Configure</source>
        <translation>Configura</translation>
    </message>
    <message>
        <location filename="main.ui" line="268"/>
        <location filename="main.ui" line="271"/>
        <source>Change language</source>
        <translation>Canvia l&apos;idioma</translation>
    </message>
    <message>
        <location filename="main.ui" line="276"/>
        <location filename="main.ui" line="279"/>
        <location filename="main.ui" line="293"/>
        <source>Change dictionary</source>
        <translation>Canvia el diccionari</translation>
    </message>
    <message>
        <location filename="main.ui" line="287"/>
        <location filename="main.ui" line="290"/>
        <source>Change &amp;dictionary</source>
        <translation>Canvia el &amp;diccionari</translation>
    </message>
    <message>
        <location filename="main.ui" line="296"/>
        <source>Ctrl+D</source>
        <translation></translation>
    </message>
    <message>
        <location filename="main.ui" line="304"/>
        <location filename="main.ui" line="307"/>
        <source>&amp;Paste</source>
        <translation>&amp;Enganxa</translation>
    </message>
    <message>
        <location filename="main.ui" line="310"/>
        <source>Ctrl+V</source>
        <translation></translation>
    </message>
    <message>
        <location filename="main.ui" line="315"/>
        <source>Select word</source>
        <translation>Selecciona paraula</translation>
    </message>
    <message>
        <location filename="main.ui" line="318"/>
        <source>Ctrl+L</source>
        <translation></translation>
    </message>
    <message>
        <location filename="main.cpp" line="43"/>
        <location filename="main.cpp" line="343"/>
        <location filename="main.cpp" line="506"/>
        <source>Report as new entry</source>
        <translation>Suggereix com a nova entrada</translation>
    </message>
    <message>
        <location filename="main.cpp" line="56"/>
        <source>cat-&gt;eng</source>
        <translation>cat-&gt;ang</translation>
    </message>
    <message>
        <location filename="main.cpp" line="61"/>
        <source>eng-&gt;cat</source>
        <translation>ang-&gt;cat</translation>
    </message>
    <message>
        <location filename="main.cpp" line="70"/>
        <source>Paste</source>
        <translation>Enganxa</translation>
    </message>
    <message>
        <location filename="main.cpp" line="101"/>
        <source>Festival executed and returned error code: </source>
        <translation>Festival ha estat executat i ha retornat el codi d&apos;error:</translation>
    </message>
    <message>
        <location filename="main.cpp" line="101"/>
        <source>Please consult the FAQ for help with this issue</source>
        <translation>Consulteu les PUF per a més ajuda</translation>
    </message>
    <message>
        <location filename="main.cpp" line="105"/>
        <source>You probably haven&apos;t installed the Catalan dictionary for Festival</source>
        <translation>Probablement no teniu el diccionari català per Festival</translation>
    </message>
    <message>
        <location filename="main.cpp" line="113"/>
        <source>Error executing Festival. Please consult the FAQ for help with this issue</source>
        <translation>Error executant Festival. Si us plau, consulteu les PUF per ajuda en aquesta incidència</translation>
    </message>
    <message>
        <location filename="main.cpp" line="117"/>
        <source>Error executing browser. Please consult the FAQ for help with this issue</source>
        <translation>Error executant el navegador. Si us plau, consulteu les PUF per ajuda en aquesta incidència</translation>
    </message>
    <message>
        <location filename="main.cpp" line="398"/>
        <location filename="main.cpp" line="459"/>
        <source>Cannot open dictionary file. Check configuration directory and permissions</source>
        <translation>No es pot obrir el diccionari. Comproveu el directori i els permisos del diccionari</translation>
    </message>
    <message>
        <location filename="main.cpp" line="449"/>
        <source>You have to write a word. The word has to start with a letter.</source>
        <translation>Heu d&apos;escriure una paraula. La paraula ha de començar amb una lletra.</translation>
    </message>
    <message>
        <location filename="main.cpp" line="505"/>
        <source>Exact match not found</source>
        <translation>Coincidència exacte no trobada</translation>
    </message>
    <message>
        <location filename="main.cpp" line="511"/>
        <source>Send comment(s)</source>
        <translation>Envia comentari(s)</translation>
    </message>
    <message>
        <location filename="main.cpp" line="627"/>
        <source>There is no configuration or old configuration. A configuration dialog will now open</source>
        <translation>No hi ha configuració o és massa vella. S&apos;obrirà el diàleg de configuració</translation>
    </message>
    <message>
        <location filename="main.cpp" line="732"/>
        <location filename="main.cpp" line="756"/>
        <source>Sending...</source>
        <translation>Enviant...</translation>
    </message>
    <message>
        <location filename="main.cpp" line="751"/>
        <source>You must type something</source>
        <translation>Heu d&apos;escriure quelcom</translation>
    </message>
    <message>
        <location filename="main.cpp" line="762"/>
        <source>Action cancelled</source>
        <translation>Acció cancelada</translation>
    </message>
    <message>
        <location filename="main.cpp" line="771"/>
        <source>Correctly sent!</source>
        <translation>Correctament enviat!</translation>
    </message>
    <message>
        <location filename="main.cpp" line="774"/>
        <source>Problem sending: </source>
        <translation>Problema enviant:</translation>
    </message>
</context>
<context>
    <name>MyLineEdit</name>
    <message>
        <location filename="mylineedit.cpp" line="79"/>
        <source>Read</source>
        <translation>Llegir</translation>
    </message>
</context>
<context>
    <name>Suggeriment</name>
    <message>
        <location filename="suggeriment.ui" line="38"/>
        <source>Send comment(s)</source>
        <translation>Envia comentari(s)</translation>
    </message>
    <message>
        <location filename="suggeriment.ui" line="69"/>
        <source>Add/correct usage notes</source>
        <translation>Afegeix/corregeix notes d&apos;ús</translation>
    </message>
    <message>
        <location filename="suggeriment.ui" line="93"/>
        <source>Word</source>
        <translation>Paraula</translation>
    </message>
    <message>
        <location filename="suggeriment.ui" line="109"/>
        <source>Add/correct translation</source>
        <translation>Afegeix/corregeix traducció</translation>
    </message>
    <message>
        <location filename="suggeriment.ui" line="134"/>
        <source>&amp;Cancel</source>
        <translation></translation>
    </message>
    <message>
        <location filename="suggeriment.ui" line="141"/>
        <source>Alt+C</source>
        <translation></translation>
    </message>
    <message>
        <location filename="suggeriment.ui" line="154"/>
        <source>Add/correct usage examples</source>
        <translation>Afegeix/corregeix exemples d&apos;ús</translation>
    </message>
    <message>
        <location filename="suggeriment.ui" line="179"/>
        <source>&amp;Ok</source>
        <translation></translation>
    </message>
    <message>
        <location filename="suggeriment.ui" line="186"/>
        <source>Alt+O</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <location filename="trayicon.cpp" line="57"/>
        <source>Hide</source>
        <translation>Amaga</translation>
    </message>
    <message>
        <location filename="trayicon.cpp" line="60"/>
        <source>Show</source>
        <translation>Mostra</translation>
    </message>
    <message>
        <location filename="trayicon.cpp" line="67"/>
        <source>Quit</source>
        <translation>Abandona</translation>
    </message>
</context>
</TS>
